@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Directory::Stylish;
-$Mojolicious::Plugin::Directory::Stylish::VERSION = '1.000';
+$Mojolicious::Plugin::Directory::Stylish::VERSION = '1.001';
 # ABSTRACT: Serve static files from document root with directory index using Mojolicious templates
 use strict;
 use warnings;
@@ -20,6 +20,7 @@ sub register {
     my $handler     = $args->{handler};
     my $index       = $args->{dir_index};
     my $enable_json = $args->{enable_json};
+    my $auto_index  = $args->{auto_index} // 1;
 
     my $css         = $args->{css} || 'style';
     my $render_opts = $args->{render_opts} || {};
@@ -43,10 +44,11 @@ sub register {
                 if ( $index && ( my $file = locate_index( $index, $path ) ) ) {
                     return render_file( $c, $file );
                 }
-
-                $c->stash(css => $css),
-                render_indexes( $c, $path, $render_opts, $enable_json )
-                    unless ( $c->tx->res->code );
+                if ( $auto_index ) {
+                  $c->stash(css => $css),
+                    render_indexes( $c, $path, $render_opts, $enable_json )
+                        unless ( $c->tx->res->code );
+                }
             }
         },
     );
@@ -156,7 +158,7 @@ Mojolicious::Plugin::Directory::Stylish - Serve static files from document root
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -191,7 +193,7 @@ If root is a file, serve only root file.
 =head2 C<auto_index>
 
   # Mojolicious::Lite
-  plugin Directory => { auto_index => 0 };
+  plugin 'Directory::Stylish' => { auto_index => 0 };
 
 Automatically generate index page for directory, default true.
 
@@ -238,15 +240,15 @@ A name for the template to use for the index page.
 
 =over 2
 
-=item $files: Array[Hash]
+=item * $files: Array[Hash]
 
 list of files and directories
 
-=item $current: String
+=item * $current: String
 
 current path
 
-=item $css: String
+=item * $css: String
 
 name of template with css that you want to include
 
@@ -305,12 +307,19 @@ Many thanks to the contributors for their work.
 
 =item * ChinaXing
 
+=item * Su-Shee
+
 =back
 
 =head1 SEE ALSO
 
-L<Mojolicious::Plugin::Directory>
-L<Plack::App::Directory>
+=over 2
+
+=item * L<Mojolicious::Plugin::Directory>
+
+=item * L<Plack::App::Directory>
+
+=back
 
 =head1 ORIGINAL AUTHOR
 
